root

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2025 License: MIT Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Cmd = &cobra.Command{
		Use:   "nonodox",
		Short: "NoNodox is a tool for local development of Cartesi coprocessor applications",
		Long:  "This tool listens for input events, processes notices linked to an input, and executes them on-chain (anvil).",
		Run: func(cmd *cobra.Command, args []string) {
			if configPath == "" {
				cfg = &configs.Config{
					AnvilWsURL:             "ws://localhost:8545",
					GraphQLURL:             "http://localhost:8081/graphql",
					DappAddress:            "0xab7528bb862fb57e8a2bcd567a2e929a0be56a5e",
					AnvilHttpURL:           "http://localhost:8545",
					AnvilPrivateKey:        "ac0974bec39a17e36ba4a6b4d238ff944bacb478cbed5efcae784d7bf4f2ff80",
					InputBoxAddress:        "0x59b22D57D4f067708AB0c00552767405926dc768",
					NonodoHttpPort:         "8081",
					AnvilInputBoxBlock:     "7",
					CoprocessorMockAddress: "0x9A9f2CCfdE556A7E9Ff0848998Aa4a0CFD8863AE",
				}
			} else {
				var err error
				cfg, err = configs.LoadConfig(configPath)
				if err != nil {
					slog.Error("Failed to load configuration file", "error", err)
					os.Exit(1)
				}
			}
			run()
		},
	}
)

Functions

func NewFindOutputsByIdUseCase

func NewFindOutputsByIdUseCase(graphqlUrl string, httpClient graphql.Doer) (*usecase.FindOutputsByIdUseCase, error)

func NewInputReader added in v0.1.1

func NewInputReader(cfg2 *configs.Config) (*evm_reader.InputReader, error)

func NewTaskReader added in v0.1.1

func NewTaskReader(cfg2 *configs.Config, mockCoprocessorAddress common.Address) (*evm_reader.TaskReader, error)

Types

This section is empty.

Jump to